#
# spec file for package libnvme
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1

Name:           libnvme
Version:        1.0
Release:        150400.3.9.3
Summary:        Linux-native nvme device management library
License:        LGPL-2.1-or-later
URL:            https://github.com/linux-nvme/libnvme/
Source0:        libnvme-%{version}.tar.gz
Patch1:         0001-fabrics-Lower-log-level-in-__nvmf_add_ctrl.patch
Patch2:         0002-fabrics-Remove-double-connection-error-logging.patch
Patch3:         0003-fabrics-Introduce-connection-connect-error-mapping.patch
Patch4:         0004-libnvme-Export-nvme_ctrl_get_config.patch
Patch5:         0005-tree-Factor-lookup-code-for-controller.patch
Patch6:         0006-fabrics-Consider-config-from-file-when-adding-new-co.patch
Patch7:         0007-python-add-missing-ctrl-attrs-to-Python-bindings.patch
Patch8:         0008-libnvme-accessors-for-dhchap_key-variables.patch
Patch9:         0009-fabrics-Update-controller-authentication-in-nvmf_add.patch
Patch10:        0010-json-fixup-dhchap_ctrl_key-definitions.patch
Patch11:        0011-tree-rename-controller-dhchap_key-to-dhchap_ctrl_key.patch
Patch12:        0012-Parse-dhchap_host_key-on-controller-level.patch
Patch13:        0013-json-schema-add-dhchap_key-details-to-host-section.patch
Patch14:        0014-nvme-tree-avoid-segfault-if-auth-keys-are-unavailabl.patch
Patch15:        0015-fabrics-restructrure-nvmf_get_discovery_log.patch
Patch16:        0016-tree-simplifiy-nvme_subsystem_lookup_namespace.patch
Patch17:        0017-tree-make-nvme_subsystem_scan_namespace-idempotent.patch
Patch18:        0018-tree-make-nvme_ctrl_scan_namespace-idempotent.patch
Patch19:        0019-Fix-llx-lx-build-warnings-on-powerpc.patch
Patch20:        0020-fabrics-sanitize-dump-config-output.patch
Patch21:        0021-fabrics-Fix-build_options-return-values.patch
Patch22:        0022-fabrics-Duplicate-strings-when-merging-configs.patch
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libjson-c-devel
BuildRequires:  libuuid-devel
BuildRequires:  make
BuildRequires:  meson >= 0.47.0
BuildRequires:  openssl-devel
BuildRequires:  python3-devel
BuildRequires:  swig

%description
Provides library functions for accessing and managing NVMe devices on a Linux
system.

%package -n %{name}%{sover}
Summary:        Linux-native nvme device management library

%description -n %{name}%{sover}
Provides library functions for accessing and managing NVMe devices on a Linux
system.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{sover} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n	python3-libnvme
Summary:        Python binding for %{name}

%description -n python3-libnvme
Provides library functions for accessing and managing NVMe devices on a Linux
system.

Python binding part.

%prep
%autosetup -p1

%build
%meson \
    -Ddocs=man
%meson_build

%install
%meson_install

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%doc README.md
%{_libdir}/%{name}.so.%{sover}*

%files devel
%doc README.md
%{_includedir}/*
%{_libdir}/%{name}*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/*/*

%files -n python3-libnvme
%{python3_sitearch}/libnvme
%{python3_sitearch}/libnvme/*.so
%{python3_sitearch}/libnvme/__init__.py
%{python3_sitearch}/libnvme/nvme.py

%changelog
* Tue Nov 15 2022 dwagner@suse.de
- fabrics: Duplicate strings when merging configs (bsc#1205019)
  * add 0022-fabrics-Duplicate-strings-when-merging-configs.patch
- remove unused patch (duplicated of patch #0013)
  * remove 0022-json-schema-add-dhchap_key-details-to-host-section.patch
* Wed Sep 21 2022 dwagner@suse.de
- Fixes for controller authentication (bsc#1201501 bsc#1201700 bsc#1201701 bsc#1201717)
  * add 0007-python-add-missing-ctrl-attrs-to-Python-bindings.patch
  * add 0008-libnvme-accessors-for-dhchap_key-variables.patch
  * add 0009-fabrics-Update-controller-authentication-in-nvmf_add.patch
  * add 0010-json-fixup-dhchap_ctrl_key-definitions.patch
  * add 0011-tree-rename-controller-dhchap_key-to-dhchap_ctrl_key.patch
  * add 0012-Parse-dhchap_host_key-on-controller-level.patch
  * add 0013-json-schema-add-dhchap_key-details-to-host-section.patch
  * add 0014-nvme-tree-avoid-segfault-if-auth-keys-are-unavailabl.patch
  * add 0015-fabrics-restructrure-nvmf_get_discovery_log.patch
- Subsystem scanning logic fixes
  * add 0016-tree-simplifiy-nvme_subsystem_lookup_namespace.patch
  * add 0017-tree-make-nvme_subsystem_scan_namespace-idempotent.patch
  * add 0018-tree-make-nvme_ctrl_scan_namespace-idempotent.patch
- Fix PowerPC build warnings
  * add 0019-Fix-llx-lx-build-warnings-on-powerpc.patch
- Fabrics fixes
  * add 0020-fabrics-sanitize-dump-config-output.patch
  * add 0021-fabrics-Fix-build_options-return-values.patch
* Fri Jun  3 2022 dwagner@suse.de
- Reduce log noise and export error codes (bsc#1199994 bsc#1199503)
  * add 0001-fabrics-Lower-log-level-in-__nvmf_add_ctrl.patch
  * add 0002-fabrics-Remove-double-connection-error-logging.patch
  * add 0003-fabrics-Introduce-connection-connect-error-mapping.patch
- Apply configuration from JSON file (bsc#1199503)
  * add 0004-libnvme-Export-nvme_ctrl_get_config.patch
  * add 0005-tree-Factor-lookup-code-for-controller.patch
  * add 0006-fabrics-Consider-config-from-file-when-adding-new-co.patch
* Fri Apr  8 2022 daniel.wagner@suse.com
- Update to version 1.0:
  * tree: Remove default port setting for TCP and RDMA ports
  * tree: add 'f_args' argument to pass user data to the filter function
  * tree: remove 'ctrl_get_ana_state()'
  * tree: add namespace path iterators
  * tree: filter out namespaces
  * tree: update nvme_scan_filter_t usage
* Fri Apr  1 2022 daniel.wagner@suse.com
- Update to version 1.0-rc8:
  * types: Add support for get log - MI Command Supported
  * types: Add new Identify constant
  * types: Update persistent event entry struct added new fields
  * types: Add Host Initiated Data Gen Number to telemetry log struct
  * tree: always allocate config file in nvme_read_config()
  * tree: rework nvme_scan_subsystem()
  * tree: make subsystem name mandatory in nvme_scan_ctrl()
  * tree: move nvme_init_subsystem() into nvme_lookup_subsystem()
  * tree: do not return error when filtering out subsystems
  * tree: add debugging messages during scanning
  * tree: Handle NULL subsysname in nvme_scan_ctrl()
  * tree: Fix subsystem initialization in nvme_scan_ctrl()
  * tree: Fix leaking 'name' in nvme_subsystem_lookup_namespace()
  * tree: Avoid dereferencing nvme_subsystem_t before its check for NULL
  * tree: Clarify NULL return values from nvme_get_attr()
  * fabrics: Invoke nvmf_dim() with provided tas argument
  * fabrics: add 'nvmf_update_config()'
  * fabrics: Avoid out of bounds string chomping
  * fabrics: Free old traddr in nvmf_add_ctrl
  * fabrics: update log level for write failures
  * fabrics: Streamlining documentation
  * fabrics: Fix leaking ctrl in nvmf_connect_disc_entry()
  * fabrics: Add missing break in a switch
  * ioctl: Remove attribute packed and alignedof for args structs
  * ioctl: Align arguments indentation with braces
  * json: fix endless loop scanning for controllers
  * Remove nvme_init_id_ns
  * Add lbstm support for create-ns
  * documentation updates
* Fri Mar 18 2022 daniel.wagner@suse.com
- Update to version 1.0-rc7:
  * linux: fixup log page offset in nvme_get_log_page()
  * tree: Add support for default trsvcid for all controllers (bsc#1195858)
  * tree: fixup coredump during nvme discover
* Fri Mar 11 2022 daniel.wagner@suse.com
- Update to version 1.0-rc6:
  * tree: add nvme_ctrl_get_ana_state() (bsc#1195938)
  * tree: link paths to namespaces in nvme_subsystem_scan_namespace() (bsc#1195938)
  * ioctl.h: ns list bug fix (wrong cns value)
  * types.h: Key Value Command Set Identifier added (NVME_CSI_KV)
  * types: fix status code type bug (wrong masking)
* Tue Mar  8 2022 daniel.wagner@suse.com
- Update License information. The library is released under
  LGPL-2.1-or-later and not LGPL-2.1-only.
* Thu Mar  3 2022 daniel.wagner@suse.com
- Update to version 1.0-rc5:
  * ioctl: Set lsp to action in nvme_get_log_persistent_event (bsc#1196121)
  * tree: Ignore traddr case in nvme_lookup_ctrl() (bsc#1194025)
  * fabrics: Do not swap bytes for system uuid (bsc#1196565)
  * documentation updates
* Tue Feb 22 2022 daniel.wagner@suse.com
- Update to version 1.0-rc4:
  * fabrics: add default port number for NVMe/TCP I/O controllers
  * linux: Update size when telemetry controller initiated data is unavailable
  * add cdw13 for set_feature_args structure
  * Add support for TP8010
  * Documentation cleanups
* Fri Feb 11 2022 daniel.wagner@suse.com
- Update to version v1.0-rc3:
  * Properly create manuals/documentation
  * Fix memleaks in __nvme_free_ns() and nvme_scan_subsystem()
  * nvme: get log domain id included in Log Specific Identifier
  * nvme: Add nulbaf(Number of Unique Capability LBA Formats) field on nvmd_id_ns
  * ioctl: Add identify ioctl for CNS 09h, 0Ah
  * nvme: Add Enhanced Controller Meta Data(FID: 0x7D)
  * nvme: Add Supported Capacity Configuration List log page(LID: 0x11)
  * tree: do not set dhchap_key to 'none'
  * tree: restart controller lookup
  * tree: fixup memory leak in nvme_scan_ctrl()
  * Rename nvme_path_get_subsystem()
  * Remove nvme_reset_topology()
- Use precompiled documentation instead regenerating it
* Tue Feb  1 2022 daniel.wagner@suse.com
- Update to version 1.0~2:
  * Add fabrics config option 'tls'
  * Logging infrastructure reworked (API break)
  * Changed argument structs layout (API break)
  * Changed scan API (API break)
  * Fixed ctrl_loss_tmo handling concerning values of '-1'
  * Various build fixes
* Wed Jan 19 2022 daniel.wagner@suse.com
- Remove Provide for python package.
- Remove explicit tar file name for setup step.
* Tue Jan 18 2022 daniel.wagner@suse.com
- Use osc_scm to manage upstream input source.
* Tue Jan 18 2022 daniel.wagner@suse.com
- Fix Source URL
* Fri Jan 14 2022 daniel.wagner@suse.com
- Initial package creation for libnvme
